@@ -12,89 +12,37 @@
 #include <iostream>
 #include <string>
 #include <utility>
+#include <signal.h>
 
 #ifdef __GNUC__
 #include <stdio.h>
 #include <execinfo.h>
-#include <signal.h>
 #include <stdlib.h>
 #include <unistd.h>
 #endif
 
+#include "xeus/xeus_context.hpp"
 #include "xeus/xkernel.hpp"
 #include "xeus/xkernel_configuration.hpp"
-#include "xeus/xserver.hpp"
+#include "xeus/xserver_shell_main.hpp"
+#include "xeus/xinterpreter.hpp"
 
 #include "pybind11/embed.h"
 #include "pybind11/pybind11.h"
 
 #include "xeus-python/xinterpreter.hpp"
+#include "xeus-python/xinterpreter_raw.hpp"
 #include "xeus-python/xdebugger.hpp"
 #include "xeus-python/xpaths.hpp"
 #include "xeus-python/xeus_python_config.hpp"
-
-#ifdef __GNUC__
-void handler(int sig)
-{
-    void* array[10];
-
-    // get void*'s for all entries on the stack
-    size_t size = backtrace(array, 10);
-
-    // print out all the frames to stderr
-    fprintf(stderr, "Error: signal %d:\n", sig);
-    backtrace_symbols_fd(array, size, STDERR_FILENO);
-    exit(1);
-}
-#endif
+#include "xeus-python/xutils.hpp"
 
 namespace py = pybind11;
 
-bool should_print_version(int argc, char* argv[])
-{
-    for (int i = 0; i < argc; ++i)
-    {
-        if (std::string(argv[i]) == "--version")
-        {
-            return true;
-        }
-    }
-    return false;
-}
-
-std::string extract_filename(int argc, char* argv[])
-{
-    std::string res = "";
-    for (int i = 0; i < argc; ++i)
-    {
-        if ((std::string(argv[i]) == "-f") && (i + 1 < argc))
-        {
-            res = argv[i + 1];
-            for (int j = i; j < argc - 2; ++j)
-            {
-                argv[j] = argv[j + 2];
-            }
-            argc -= 2;
-            break;
-        }
-    }
-    return res;
-}
-
-void print_pythonhome()
-{
-    std::setlocale(LC_ALL, "en_US.utf8");
-    wchar_t* ph = Py_GetPythonHome();
-
-    char mbstr[1024];
-    std::wcstombs(mbstr, ph, 1024);
-
-    std::clog << "PYTHONHOME set to " << mbstr << std::endl;
-}
 
 int main(int argc, char* argv[])
 {
-    if (should_print_version(argc, argv))
+    if (xpyt::should_print_version(argc, argv))
     {
         std::clog << "xpython " << XPYT_VERSION << std::endl;
         return 0;
@@ -113,8 +61,12 @@ int main(int argc, char* argv[])
     // Registering SIGSEGV handler
 #ifdef __GNUC__
     std::clog << "registering handler for SIGSEGV" << std::endl;
-    signal(SIGSEGV, handler);
+    signal(SIGSEGV, xpyt::sigsegv_handler);
+
+    // Registering SIGINT and SIGKILL handlers
+    signal(SIGKILL, xpyt::sigkill_handler);
 #endif
+    signal(SIGINT, xpyt::sigkill_handler);
 
     // Setting Program Name
     static const std::string executable(xpyt::get_python_path());
@@ -128,7 +80,7 @@ int main(int argc, char* argv[])
 
     // Setting PYTHONHOME
     xpyt::set_pythonhome();
-    print_pythonhome();
+    xpyt::print_pythonhome();
 
     // Instanciating the Python interpreter
     py::scoped_interpreter guard;
@@ -146,14 +98,27 @@ int main(int argc, char* argv[])
     }
     delete[] argw;
 
+    using context_type = xeus::xcontext_impl<zmq::context_t>;
+    using context_ptr = std::unique_ptr<context_type>;
+    context_ptr context = context_ptr(new context_type());
+
     // Instantiating the xeus xinterpreter
-    using interpreter_ptr = std::unique_ptr<xpyt::interpreter>;
-    interpreter_ptr interpreter = interpreter_ptr(new xpyt::interpreter());
+    bool raw_mode = xpyt::extract_option("-r", "--raw", argc, argv);
+    using interpreter_ptr = std::unique_ptr<xeus::xinterpreter>;
+    interpreter_ptr interpreter;
+    if (raw_mode)
+    {
+        interpreter = interpreter_ptr(new xpyt::raw_interpreter());
+    }
+    else
+    {
+        interpreter = interpreter_ptr(new xpyt::interpreter());
+    }
 
     using history_manager_ptr = std::unique_ptr<xeus::xhistory_manager>;
     history_manager_ptr hist = xeus::make_in_memory_history_manager();
 
-    std::string connection_filename = extract_filename(argc, argv);
+    std::string connection_filename = xpyt::extract_parameter("-f", argc, argv);
 
 #ifdef XEUS_PYTHON_PYPI_WARNING
     std::clog <<
@@ -171,11 +136,12 @@ int main(int argc, char* argv[])
 
         xeus::xkernel kernel(config,
                              xeus::get_user_name(),
+                             std::move(context),
                              std::move(interpreter),
+                             xeus::make_xserver_shell_main,
                              std::move(hist),
                              xeus::make_console_logger(xeus::xlogger::msg_type,
                                                        xeus::make_file_logger(xeus::xlogger::content, "xeus.log")),
-                             xeus::make_xserver_shell_main,
                              xpyt::make_python_debugger,
                              debugger_config);
 
@@ -190,10 +156,11 @@ int main(int argc, char* argv[])
     else
     {
         xeus::xkernel kernel(xeus::get_user_name(),
+                             std::move(context),
                              std::move(interpreter),
+                             xeus::make_xserver_shell_main,
                              std::move(hist),
                              nullptr,
-                             xeus::make_xserver_shell_main,
                              xpyt::make_python_debugger,
                              debugger_config);
 
