@@ -52,28 +52,41 @@ namespace xpyt
         return "\033[0;34m" + text + "\033[0m";
     }
 
-    zmq::message_t pybytes_to_zmq_message(py::bytes bytes)
+    std::string highlight(const std::string& code)
+    {
+        py::object py_highlight = py::module::import("pygments").attr("highlight");
+        // py::module::import("pygments").attr("formatters") does NOT work due
+        // to side effects when importing pygments
+        py::object formatter = py::module::import("pygments.formatters").attr("TerminalFormatter");
+
+        py::object lexer = py::module::import("pygments.lexers").attr("Python3Lexer");
+
+        return py::str(py_highlight(code, lexer(), formatter()));
+    }
+
+    xeus::binary_buffer pybytes_to_cpp_message(py::bytes bytes)
     {
         char* buffer;
         Py_ssize_t length;
         PyBytes_AsStringAndSize(bytes.ptr(), &buffer, &length);
-        return zmq::message_t(buffer, static_cast<std::size_t>(length));
+        return xeus::binary_buffer(buffer, buffer + static_cast<std::size_t>(length));
     }
 
-    py::list zmq_buffers_to_pylist(const std::vector<zmq::message_t>& buffers)
+    py::list cpp_buffers_to_pylist(const xeus::buffer_sequence& buffers)
     {
         py::list bufferlist;
-        for (const zmq::message_t& buffer : buffers)
+        for (const xeus::binary_buffer& buffer : buffers)
         {
-            const char* buf = buffer.data<const char>();
-            bufferlist.attr("append")(py::memoryview(py::bytes(buf)));
+            bufferlist.attr("append")(
+                py::memoryview(py::bytes(buffer.data(), buffer.size()))
+            );
         }
         return bufferlist;
     }
 
-    std::vector<zmq::message_t> pylist_to_zmq_buffers(const py::object& bufferlist)
+    xeus::buffer_sequence pylist_to_cpp_buffers(const py::object& bufferlist)
     {
-        std::vector<zmq::message_t> buffers;
+        xeus::buffer_sequence buffers;
 
         // Cannot iterate over NoneType, returning immediately with an empty vector
         if (bufferlist.is_none())
@@ -86,11 +99,11 @@ namespace xpyt
             if (py::isinstance<py::memoryview>(buffer))
             {
                 py::bytes bytes = buffer.attr("tobytes")();
-                buffers.push_back(pybytes_to_zmq_message(bytes));
+                buffers.push_back(pybytes_to_cpp_message(bytes));
             }
             else
             {
-                buffers.push_back(pybytes_to_zmq_message(buffer.cast<py::bytes>()));
+                buffers.push_back(pybytes_to_cpp_message(buffer.cast<py::bytes>()));
             }
         }
         return buffers;
@@ -103,8 +116,7 @@ namespace xpyt
         py_msg["parent_header"] = msg.parent_header().get<py::object>();
         py_msg["metadata"] = msg.metadata().get<py::object>();
         py_msg["content"] = msg.content().get<py::object>();
-        py_msg["buffers"] = zmq_buffers_to_pylist(msg.buffers());
-
+        py_msg["buffers"] = cpp_buffers_to_pylist(msg.buffers());
         return py_msg;
     }
 
