@@ -24,7 +24,7 @@
 #include "pybind11/pybind11.h"
 
 #include <stdio.h>
-#ifdef WIN32
+#ifdef _WIN32
 #include <direct.h>
 #define getcwd _getcwd
 #else
@@ -43,7 +43,7 @@ std::string get_current_working_directory()
     (void*)r;
     std::string current_dir(buff);
     //current_dir += '/';
-#ifdef WIN32
+#ifdef _WIN32
     std::replace(current_dir.begin(), current_dir.end(), '\\', '/');
 #endif
     return current_dir;
@@ -712,6 +712,8 @@ bool debugger_client::test_debug_info()
 
 bool debugger_client::test_inspect_variables()
 {
+    attach();
+
     std::string code = "i=4\nj=i+4\nk=j-3\n";
     m_client.send_on_shell("execute_request", make_execute_request(code));
     m_client.receive_on_shell();
@@ -721,19 +723,20 @@ bool debugger_client::test_inspect_variables()
 
     nl::json vars = rep["content"]["body"]["variables"];
 
-    auto check_var = [&vars](const std::string& name, int value) {
+    auto check_var = [&vars](const std::string& name, const std::string& value) {
         auto x = std::find_if(vars.begin(), vars.end(), [&name](const nl::json& var) {
             return var.is_object() && var.value("name", "") == name;
         });
         if (x == vars.end())
         {
+            std::cout << "missing " << name << std::endl;
             return false;
         }
         nl::json var = *x;
         return var["value"] == value && var["variablesReference"] == 0;
     };
 
-    bool res = check_var("i", 4) && check_var("j", 8) && check_var("k", 5);
+    bool res = check_var("i", "4") && check_var("j", "8") && check_var("k", "5");
     return res;
 }
 
@@ -748,7 +751,7 @@ class Person:
         return {
             "text/html": """<img src="{}">
                   <div><i class='fa-user fa'></i>: {}</div>
-                  <div><i class='fa-map fa'></i>: {}</div>""".format(self.picture, self.name, self.address) 
+                  <div><i class='fa-map fa'></i>: {}</div>""".format(self.picture, self.name, self.address)
         }
 )RICH";
 
@@ -1130,7 +1133,7 @@ TEST(debugger, set_exception_breakpoints)
         debugger_client deb(context, KERNEL_JSON, "debugger_set_exception_breakpoints.log");
         bool res = deb.test_set_exception_breakpoints();
         deb.shutdown();
-        std::this_thread::sleep_for(2s);
+        std::this_thread::sleep_for(5s);
         EXPECT_TRUE(res);
         notify_done();
     }
